
function getNewTree(world,posX,posY,objType)
	local fileDir = love.filesystem.enumerate("/Trees")
	
	local treeInstance = {}
	randomize()
	treeInstance.img = love.graphics.newImage("/Trees/" .. fileDir[math.random(#fileDir)])
	treeInstance.position = {x=posX,y=posY}	
	return treeInstance
end

function getNewBox(world,img,posX,posY,objType)
	boxInstance = {}
	if img ~= nil then
		boxInstance.img = img
	else
		local fileDir = love.filesystem.enumerate("/Box")
		randomize()
		boxInstance.img = love.graphics.newImage("/Box/" .. fileDir[math.random(#fileDir)])
	end
	boxInstance.body = love.physics.newBody(world,posX,posY,objType)
	boxInstance.shape = love.physics.newRectangleShape(boxInstance.img:getWidth() / 2,boxInstance.img:getHeight() / 2,boxInstance.img:getWidth(), boxInstance.img:getHeight())
	boxInstance.fixture = love.physics.newFixture(boxInstance.body,boxInstance.shape)
	
	return boxInstance
end

function getNewGround(world,img,posX,posY,objType)
	groundInstance = {}
	
	if img ~= nil then
		groundInstance.img = img
	else
		local fileDir = love.filesystem.enumerate("/Ground")
		randomize()
		groundInstance.img = love.graphics.newImage("/Ground/" .. fileDir[math.random(#fileDir)])
	end
	groundInstance.body = love.physics.newBody(world,posX,posY,objType)
	groundInstance.shape = love.physics.newRectangleShape(groundInstance.img:getWidth() / 2,groundInstance.img:getHeight() / 2,groundInstance.img:getWidth(), groundInstance.img:getHeight())
	groundInstance.fixture = love.physics.newFixture(groundInstance.body,groundInstance.shape)
	
	return groundInstance
end

function getNewMap(world,width,height)
	local mapInstance = {}
	mapInstance.img = love.graphics.newImage("/Box/littleBlock.png")
	mapInstance.map = {}
	for i = 1,width,1 do
	mapInstance.map[i] = {}
		for j = 1,height,1 do
			mapInstance.map[i][j] = {}
			mapInstance.map[i][j].body = love.physics.newBody(world, (i + 5 ) * mapInstance.img:getWidth(),(j + 20) * mapInstance.img:getHeight(),"static") 
			mapInstance.map[i][j].shape = love.physics.newRectangleShape((mapInstance.img:getWidth() / 2) ,mapInstance.img:getHeight() / 2,mapInstance.img:getWidth(),mapInstance.img:getHeight())
			mapInstance.map[i][j].fixture = love.physics.newFixture(mapInstance.map[i][j].body,mapInstance.map[i][j].shape)
		end
	end
	
	return mapInstance
	
end

function randomize()
	math.randomseed(os.date("%S"))
	math.random()
	math.random()
	math.random()
end

local objectFactory = {
	getNewTree = getNewTree,
	getNewBox = getNewBox,
	getNewGround = getNewGround,
	getNewMap = getNewMap
}

return objectFactory